==> hs-glib-0.12.3.1p1.tgz: lib/ghc/glib-0.12.3.1/register.sh <==
#!/bin/sh
echo 'name: glib
version: 0.12.3.1
id: glib-0.12.3.1-8ac5b4e3ebf09c745ad0f6b285d2dd5a

license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@lists.sourceforge.net
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
package-url:
synopsis: Binding to the GLIB library for Gtk2Hs.
description: The GNU Library is a collection of C data structures and utility
             function for dealing with Unicode. This package only binds as
             much functionality as required to support the packages that
             wrap libraries that are themselves based on GLib.
category: System
author: Axel Simon, Duncan Coutts
pkgpath: devel/hs-glib
exposed: True
exposed-modules: System.Glib System.Glib.GError
                 System.Glib.Properties System.Glib.Attributes System.Glib.Signals
                 System.Glib.MainLoop System.Glib.GDateTime System.Glib.GObject
                 System.Glib.Utils System.Glib.StoreValue System.Glib.FFI
                 System.Glib.Flags System.Glib.UTFString System.Glib.Types
                 System.Glib.GList System.Glib.GString System.Glib.GType
                 System.Glib.GTypeConstants System.Glib.GValue
                 System.Glib.GValueTypes System.Glib.GParameter
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc/glib-0.12.3.1
library-dirs: /usr/local/lib/ghc/glib-0.12.3.1 /usr/local/lib
hs-libraries: HSglib-0.12.3.1
extra-libraries: gobject-2.0 glib-2.0 intl iconv
extra-ghci-libraries:
include-dirs: /usr/local/include/glib-2.0
              /usr/local/lib/glib-2.0/include /usr/local/include
includes:
depends: base-4.5.1.0-f38bf31a759416ec7b167d6dc132959a
         containers-0.4.2.1-75f143aa39a3e77a1ce2300025bdd8ce
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-glib-0.12.3.1/html/glib.haddock
haddock-html: /usr/local/share/doc/hs-glib-0.12.3.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-glib-0.12.4.tgz: lib/ghc/glib-0.12.4/register.sh <==
#!/bin/sh
echo 'name: glib
version: 0.12.4
id: glib-0.12.4-d1f299818663664519b8d947e0784cb7

license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@lists.sourceforge.net
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
package-url:
synopsis: Binding to the GLIB library for Gtk2Hs.
description: The GNU Library is a collection of C data structures and utility
             function for dealing with Unicode. This package only binds as
             much functionality as required to support the packages that
             wrap libraries that are themselves based on GLib.
category: System
author: Axel Simon, Duncan Coutts
pkgpath: devel/hs-glib
exposed: True
exposed-modules: System.Glib System.Glib.GError
                 System.Glib.Properties System.Glib.Attributes System.Glib.Signals
                 System.Glib.MainLoop System.Glib.GDateTime System.Glib.GObject
                 System.Glib.Utils System.Glib.StoreValue System.Glib.FFI
                 System.Glib.Flags System.Glib.UTFString System.Glib.Types
                 System.Glib.GList System.Glib.GString System.Glib.GType
                 System.Glib.GTypeConstants System.Glib.GValue
                 System.Glib.GValueTypes System.Glib.GParameter
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc/glib-0.12.4
library-dirs: /usr/local/lib/ghc/glib-0.12.4 /usr/local/lib
hs-libraries: HSglib-0.12.4
extra-libraries: gobject-2.0 glib-2.0 intl
extra-ghci-libraries:
include-dirs: /usr/local/include/glib-2.0
              /usr/local/lib/glib-2.0/include /usr/local/include
includes:
depends: base-4.6.0.1-185478ee9bcc4ae00bc1dbe06bac6937
         containers-0.5.0.0-3b8b869ec10d44736414ab5bea776319
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-glib-0.12.4/html/glib.haddock
haddock-html: /usr/local/share/doc/hs-glib-0.12.4/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
